@@ -36,10 +36,11 @@ class Recipe(object):
             if not url:
                 version = self.options.get('phantomjs-version', '1.7.0')
                 if sys.platform == 'linux2':
+                    arch = 'x86_64' in os.uname() and 'x86_64' or 'i686'
                     url = (
                         'https://phantomjs.googlecode.com/'
-                        'files/phantomjs-%s-linux-i686.tar.bz2'
-                    ) % version
+                        'files/phantomjs-%s-linux-%s.tar.bz2'
+                    ) % (version, arch)
                 elif sys.platform == 'darwin':
                     url = (
                         'https://phantomjs.googlecode.com/'
